import importlib
import sys,os

IS_FIRSTTIME = sys.path[0] != '.'

def assert_dep(name):
    assert importlib.util.find_spec(name), "需要安装 %s" % name


def login():
    import inquirer
    import demos.手机登录 as 手机登录, 二维码登录
    class 匿名登陆:
        @staticmethod
        def login():
            from pyncm.apis.login import LoginViaAnonymousAccount
            return LoginViaAnonymousAccount()
    methods = {"手机登录": 手机登录, "二维码登录": 二维码登录,"匿名登陆": 匿名登陆}
    assert methods[
        inquirer.prompt([inquirer.List("method", message="登陆方法", choices=methods)])["method"]
    ].login(), "登录失败"
    from pyncm import GetCurrentSession

    print(
        "已登录",
        GetCurrentSession().nickname,
        "用户 ID：",
        GetCurrentSession().uid,
    )
    return True


assert_dep("pyncm")
assert_dep("inquirer")
# Find pyncm from working directories first,
if IS_FIRSTTIME:
    import inquirer
    if inquirer.confirm('使用调试模式'):
        os.environ['PYNCM_DEBUG'] = 'DEBUG'
    sys.path.insert(0,'.')
    from pyncm import __version__,__file__
    print("PyNCM %s" % __version__,__file__)



__desc__ = '''user.SetWeblog API 功能演示

摘自 https://github.com/Binaryify/NeteaseCloudMusicApi

    听歌打卡
    
    说明 : 调用此接口 , 传入音乐 id, 来源 id，歌曲时间 time，更新听歌排行数据

    必选参数 : id: 歌曲 id, sourceid: 歌单或专辑 id

    可选参数 : time: 歌曲播放时间,单位为秒

    接口地址 : /scrobble

    调用例子 : /scrobble?id=518066366&sourceid=36780169&time=291
'''
from __init__ import login
assert login(), "登录失败"
from pyncm.apis.user import SetWeblog
from pprint import pprint
print(__desc__)
pprint(SetWeblog(
    [{
        'action': 'play',
        'json': {
            'download': 0,
            'end': 'playend',
            'id': input('歌曲 ID:'),
            'sourceId': input('来源 ID:'),
            'time': input('时长:') or 300,
            'type': 'song',
            'wifi': 0,
            'source' : 'list',
        }
    }]
))



# -*- coding: utf-8 -*-
"""艺术家 - Artist APIs"""
from . import WeapiCryptoRequest


@WeapiCryptoRequest
def GetArtistAlbums(artist_id: str,offset=0, total=True, limit=1000):
    """网页端 - 获取艺术家所有专辑

    Args:
        artist_id (str): 艺术家ID
        offset (int, optional): 获取偏移数. Defaults to 0.
        total (bool, optional): 是否获取全部内容. Defaults to True.
        limit (int, optional): 单次获取量. Defaults to 30.

    Returns:
        dict
    """
    return "/weapi/artist/albums/%s" % artist_id, {
        "offset": str(offset),
        "total": str(total).lower(),
        "limit": str(limit)
    }

@WeapiCryptoRequest
def GetArtistTracks(artist_id: str,offset=0, total=True, limit=1000,order='hot'):
    """网页端 - 以某排序方式获取艺术家所有歌曲

    Args:
        artist_id (str): 艺术家ID
        offset (int, optional): 获取偏移数. Defaults to 0.
        total (bool, optional): 是否获取全部内容. Defaults to True.
        limit (int, optional): 单次获取量. Defaults to 30.
        order (str, optional): 歌曲排序方式 (hot：热度最高在前/time：时间最新在前). Defaults to 'hot'.
    Returns:
        dict
    """
    return "/weapi/v1/artist/songs", {
        "id" : str(artist_id),
        "offset": str(offset),
        "total": str(total).lower(),
        "limit": str(limit),
        "order": str(order),        
    }


@WeapiCryptoRequest
def GetArtistDetails(artist_id: str):
    """网页端 - 获取艺术家详情

    Args:
        artist_id (str): 艺术家ID    
    Returns:
        dict
    """
    return "/weapi/artist/head/info/get", {
        "id" : str(artist_id)
    }


